==> kubernetes-model-admissionregistration-4.13.3-sources.jar: annotations/io/fabric8/kubernetes/api/model/authorization/v1/SelfSubjectAccessReviewFluent.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface SelfSubjectAccessReviewFluent<A extends SelfSubjectAccessReviewFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public SelfSubjectAccessReviewFluent.MetadataNested<A> withNewMetadata();
    public SelfSubjectAccessReviewFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public SelfSubjectAccessReviewFluent.MetadataNested<A> editMetadata();
    public SelfSubjectAccessReviewFluent.MetadataNested<A> editOrNewMetadata();
    public SelfSubjectAccessReviewFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public SelfSubjectAccessReviewSpec getSpec();
    public SelfSubjectAccessReviewSpec buildSpec();
    public A withSpec(SelfSubjectAccessReviewSpec spec);
    public Boolean hasSpec();
    public SelfSubjectAccessReviewFluent.SpecNested<A> withNewSpec();
    public SelfSubjectAccessReviewFluent.SpecNested<A> withNewSpecLike(SelfSubjectAccessReviewSpec item);
    public SelfSubjectAccessReviewFluent.SpecNested<A> editSpec();
    public SelfSubjectAccessReviewFluent.SpecNested<A> editOrNewSpec();
    public SelfSubjectAccessReviewFluent.SpecNested<A> editOrNewSpecLike(SelfSubjectAccessReviewSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public SubjectAccessReviewStatus getStatus();
    public SubjectAccessReviewStatus buildStatus();
    public A withStatus(SubjectAccessReviewStatus status);
    public Boolean hasStatus();
    public A withNewStatus(Boolean allowed,Boolean denied,String evaluationError,String reason);
    public SelfSubjectAccessReviewFluent.StatusNested<A> withNewStatus();
    public SelfSubjectAccessReviewFluent.StatusNested<A> withNewStatusLike(SubjectAccessReviewStatus item);
    public SelfSubjectAccessReviewFluent.StatusNested<A> editStatus();
    public SelfSubjectAccessReviewFluent.StatusNested<A> editOrNewStatus();
    public SelfSubjectAccessReviewFluent.StatusNested<A> editOrNewStatusLike(SubjectAccessReviewStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<SelfSubjectAccessReviewFluent.MetadataNested<N>> {

        public N and();
        public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SelfSubjectAccessReviewSpecFluent<SelfSubjectAccessReviewFluent.SpecNested<N>> {

        public N and();
        public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SubjectAccessReviewStatusFluent<SelfSubjectAccessReviewFluent.StatusNested<N>> {

        public N and();
        public N endStatus();    }


}

==> kubernetes-model-admissionregistration-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/authorization/v1/SelfSubjectAccessReviewFluent.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface SelfSubjectAccessReviewFluent<A extends SelfSubjectAccessReviewFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public SelfSubjectAccessReviewFluent.MetadataNested<A> withNewMetadata();
    public SelfSubjectAccessReviewFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public SelfSubjectAccessReviewFluent.MetadataNested<A> editMetadata();
    public SelfSubjectAccessReviewFluent.MetadataNested<A> editOrNewMetadata();
    public SelfSubjectAccessReviewFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public SelfSubjectAccessReviewSpec getSpec();
    public SelfSubjectAccessReviewSpec buildSpec();
    public A withSpec(SelfSubjectAccessReviewSpec spec);
    public Boolean hasSpec();
    public SelfSubjectAccessReviewFluent.SpecNested<A> withNewSpec();
    public SelfSubjectAccessReviewFluent.SpecNested<A> withNewSpecLike(SelfSubjectAccessReviewSpec item);
    public SelfSubjectAccessReviewFluent.SpecNested<A> editSpec();
    public SelfSubjectAccessReviewFluent.SpecNested<A> editOrNewSpec();
    public SelfSubjectAccessReviewFluent.SpecNested<A> editOrNewSpecLike(SelfSubjectAccessReviewSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public SubjectAccessReviewStatus getStatus();
    public SubjectAccessReviewStatus buildStatus();
    public A withStatus(SubjectAccessReviewStatus status);
    public Boolean hasStatus();
    public A withNewStatus(Boolean allowed,Boolean denied,String evaluationError,String reason);
    public SelfSubjectAccessReviewFluent.StatusNested<A> withNewStatus();
    public SelfSubjectAccessReviewFluent.StatusNested<A> withNewStatusLike(SubjectAccessReviewStatus item);
    public SelfSubjectAccessReviewFluent.StatusNested<A> editStatus();
    public SelfSubjectAccessReviewFluent.StatusNested<A> editOrNewStatus();
    public SelfSubjectAccessReviewFluent.StatusNested<A> editOrNewStatusLike(SubjectAccessReviewStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<SelfSubjectAccessReviewFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SelfSubjectAccessReviewSpecFluent<SelfSubjectAccessReviewFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SubjectAccessReviewStatusFluent<SelfSubjectAccessReviewFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}
